# Real Op-Amps

The ideal op-amp element uses an ideal approximation to op-amp behavior. It has infinite slew rate and output current.

The real op-amp element uses a subcircuit to emulate a real op-amp implementation with finite slew rate and output current. Presently, the two implementation options are LM741 and LM324.

You can also modify the slew rate or output current, which will modify the circuit to change these values from the default.

These subcircuits are complicated, so you may run problems with convergence, especially if you increase the slew rate. Try decreasing the time step size if this happens.

The LM324 can act very glitchy as well if the slew rate is increased. Decreasing the time step size proportionately should fix this.